@@ -5,8 +5,12 @@
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -43,10 +47,10 @@
 
 /* = = = START-STATIC-FORWARD = = = */
 static int
-entry_length(char* name);
+entry_length(char * name);
 
 static int
-count_entries(char* name);
+count_entries(char * name);
 
 static SCM
 find_entry_value(SCM op, SCM obj, SCM test);
@@ -63,20 +67,20 @@ do_tpl_file_line(int line_delta, char const * fmt);
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static int
-entry_length(char* name)
+entry_length(char * name)
 {
-    def_ent_t**  papDefs = find_def_ent_list(name);
+    def_ent_t ** defs = find_def_ent_list(name);
     int          res     = 0;
 
-    if (papDefs == NULL)
+    if (defs == NULL)
         return 0;
 
     for (;;) {
-        def_ent_t*   pDE = *(papDefs++);
-        if (pDE == NULL)
+        def_ent_t * de = *(defs++);
+        if (de == NULL)
             break;
-        if (pDE->de_type == VALTYP_TEXT)
-            res += strlen(pDE->de_val.dvu_text);
+        if (de->de_type == VALTYP_TEXT)
+            res += (int)strlen(de->de_val.dvu_text);
         else
             res++;
     }
@@ -85,17 +89,17 @@ entry_length(char* name)
 
 
 static int
-count_entries(char* name)
+count_entries(char * name)
 {
-    def_ent_t**  papDefs = find_def_ent_list(name);
+    def_ent_t ** defs = find_def_ent_list(name);
     int          res     = 0;
 
-    if (papDefs == NULL)
+    if (defs == NULL)
         return 0;
 
     for (;;) {
-        def_ent_t*   pDE = *(papDefs++);
-        if (pDE == NULL)
+        def_ent_t * de = *(defs++);
+        if (de == NULL)
             break;
         res++;
     }
@@ -445,19 +449,25 @@ ag_scm_match_value_p(SCM op, SCM obj, SCM test)
 SCM
 ag_scm_get(SCM agName, SCM altVal)
 {
-    def_ent_t*  pE;
-    bool     x;
+    if (AG_SCM_STRING_P(agName)) {
+        bool   x;
+        char * vnm = ag_scm2zchars(agName, "vname");
+        def_ent_t * de  = find_def_ent(vnm, &x);
+        if ((de != NULL) && (de->de_type == VALTYP_TEXT))
+            return AG_SCM_STR02SCM(de->de_val.dvu_text);
+        if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+            fprintf(trace_fp, GOT_NOTHING_FMT, vnm,
+                    (de != NULL) ? "non text value" : "no value at all",
+                    current_tpl->td_file,
+                    (unsigned)cur_macro->md_line);
 
-    pE = (! AG_SCM_STRING_P(agName)) ? NULL :
-        find_def_ent(ag_scm2zchars(agName, "ag value"), &x);
-
-    if ((pE == NULL) || (pE->de_type != VALTYP_TEXT)) {
-        if (AG_SCM_STRING_P(altVal))
-            return altVal;
-        return AG_SCM_STR02SCM(zNil);
-    }
-
-    return AG_SCM_STR02SCM(pE->de_val.dvu_text);
+    } else if (OPT_VALUE_TRACE > TRACE_NOTHING)
+        fprintf(trace_fp, GET_NOTHING_FMT, current_tpl->td_file,
+                (unsigned)cur_macro->md_line);
+    
+    if (AG_SCM_STRING_P(altVal))
+        return altVal;
+    return AG_SCM_STR02SCM(zNil);
 }
 
 
@@ -679,17 +689,18 @@ ag_scm_tpl_file(SCM full)
 static SCM
 do_tpl_file_line(int line_delta, char const * fmt)
 {
+    unsigned int ln_no = (unsigned int)cur_macro->md_line;
     void * args[2] = {
         [0] = (void *)current_tpl->td_file,
-        [1] = (void *)((uintptr_t)cur_macro->md_line + line_delta)
+        [1] = (void *)(uintptr_t)(ln_no + (unsigned)line_delta)
     };
     char * buf = strrchr(args[0], DIRCH);
     if (buf != NULL)
         args[0] = buf + 1;
 
     {
-        size_t sz = strlen(fmt) + strlen(args[0]) + 24;
-        buf = ag_scribble(sz);
+        ssize_t sz = (ssize_t)(strlen(fmt) + strlen(args[0]) + 24);
+        buf = scribble_get(sz);
     }
 
     sprintfv(buf, fmt, (snv_constpointer*)args);
@@ -795,20 +806,23 @@ ag_scm_def_file_line(SCM obj, SCM fmt)
             (void *)pE->de_file,
             (void *)(uintptr_t)pE->de_line
         };
-        size_t maxlen;
+        ssize_t maxlen;
 
         buf = strrchr(args[0], DIRCH);
         if (buf != NULL)
             args[0] = buf + 1;
 
-        maxlen = strlen(args[0]) + strlen(pzFmt) + LOG10_2to32 + 1;
-        buf = ag_scribble(maxlen);
+        maxlen = (ssize_t)(
+            strlen(args[0]) + strlen(pzFmt) + LOG10_2to32 + 1);
+        buf    = scribble_get(maxlen);
         sprintfv(buf, pzFmt, (snv_constpointer*)args);
     }
 
     return AG_SCM_STR02SCM(buf);
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
