@@ -4,8 +4,12 @@
  *
  *  This module implements the FOR text macro.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -282,7 +286,7 @@ next_def(bool invert, def_ent_t** de_lst)
              *  When the "by" step is zero, force syncronization.
              */
             if (for_state->for_by == 0) {
-                for_state->for_index = ent->de_index;
+                for_state->for_index = (int)ent->de_index;
                 haveMatch = true;
             }
             break;
@@ -318,22 +322,24 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
      *       entries of the twin set.
      */
     {
-        def_ent_t* pLast = (found->de_etwin != NULL)
-                           ? found->de_etwin : found;
+        def_ent_t * lde = (found->de_etwin != NULL)
+                          ? found->de_etwin : found;
 
         if (for_state->for_from == UNASSIGNED)
-            for_state->for_from = (invert) ? pLast->de_index : found->de_index;
+            for_state->for_from = (invert)
+                ? (int)lde->de_index : (int)found->de_index;
 
         if (for_state->for_to == UNASSIGNED)
-            for_state->for_to = (invert) ? found->de_index : pLast->de_index;
+            for_state->for_to = (invert)
+                ? (int)found->de_index : (int)lde->de_index;
 
         /*
          *  "loopLimit" is intended to catch runaway ending conditions.
          *  However, if you really have a gazillion entries, who am I
          *  to stop you?
          */
-        if (loopLimit <  pLast->de_index - found->de_index)
-            loopLimit = (pLast->de_index - found->de_index) + 1;
+        if (loopLimit <  lde->de_index - found->de_index)
+            loopLimit = (lde->de_index - found->de_index) + 1;
     }
 
     /*
@@ -372,13 +378,13 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
 
         } else if (invert) {
             next_ix = (found->de_ptwin == NULL)
-                ? for_state->for_to - 1  /* last iteration !! */
-                : found->de_ptwin->de_index;
+                ? (int)(for_state->for_to - 1)  /* last iteration !! */
+                : (int)found->de_ptwin->de_index;
 
         } else {
             next_ix = (found->de_twin == NULL)
-                ? for_state->for_to + 1  /* last iteration !! */
-                : found->de_twin->de_index;
+                ? (int)(for_state->for_to + 1)  /* last iteration !! */
+                : (int)found->de_twin->de_index;
         }
 
         /*
@@ -412,6 +418,13 @@ for_by_step(templ_t * pT, macro_t * pMac, def_ent_t * found)
             ? ((next_ix < for_state->for_to) ? true : false)
             : ((next_ix > for_state->for_to) ? true : false);
 
+        if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
+            fprintf(trace_fp, FOR_ITERATION_FMT, "by-step",
+                    for_state->for_name,
+                    for_state->for_index, loopCt, next_ix,
+                    for_state->for_isfirst ? "yes" : "no",
+                    for_state->for_islast  ? "yes" : "no");
+
         switch (call_gen_block(for_state->for_env, pT, pMac+1, end_mac)) {
         case LOOP_JMP_OKAY:
         case LOOP_JMP_NEXT:
@@ -473,7 +486,7 @@ for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent)
         /*
          *  Set the global current index
          */
-        for_state->for_index = def_ent->de_index;
+        for_state->for_index = (int)def_ent->de_index;
 
         /*
          *  Advance to the next twin
@@ -482,6 +495,16 @@ for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent)
         if (def_ent == NULL)
             for_state->for_islast = true;
 
+        if (OPT_VALUE_TRACE == TRACE_EVERYTHING) {
+            int next = (def_ent == NULL)
+                ? (for_state->for_index + 1) : def_ent->de_index;
+            fprintf(trace_fp, FOR_ITERATION_FMT, "each",
+                    for_state->for_name,
+                    for_state->for_index, loopCt, next,
+                    for_state->for_isfirst ? "yes" : "no",
+                    for_state->for_islast  ? "yes" : "no");
+        }
+
         switch (call_gen_block(for_state->for_env, tpl, mac, end_mac)) {
         case LOOP_JMP_OKAY:
         case LOOP_JMP_NEXT:
@@ -502,7 +525,9 @@ for_each(templ_t * tpl, macro_t * mac, def_ent_t * def_ent)
         /*
          *  Emit the iteration separation
          */
-        fputs(for_state->for_sep_str, cur_fpstack->stk_fp);
+        if (  ( for_state->for_sep_str != NULL)
+           && (*for_state->for_sep_str != NUL))
+            fputs(for_state->for_sep_str, cur_fpstack->stk_fp);
         fflush(cur_fpstack->stk_fp);
     } leave_loop:;
 
@@ -526,7 +551,7 @@ load_for_in(char const * pzSrc, size_t srcLen, templ_t * pT, macro_t * pMac)
     pz = SPN_WHITESPACE_CHARS(pzSrc + 3);
     if (*pz == NUL)
         AG_ABEND_IN(pT, pMac, FOR_IN_LISTLESS);
-    srcLen -= pz - pzSrc;
+    srcLen -= (size_t)(pz - pzSrc);
     pzSrc = pz;
 
     {
@@ -760,19 +785,18 @@ mFunc_For(templ_t * tpl, macro_t * mac)
         lp_ct = for_each(tpl, mac, def);
     }
 
-    if (for_state->for_sep_str != NULL)
-        AGFREE(for_state->for_sep_str);
-
-    free_for_context(false);
-
     if (OPT_VALUE_TRACE >= TRACE_BLOCK_MACROS) {
-        fprintf(trace_fp, TRACE_FN_FOR_REPEAT, tpl->td_text + mac->md_name_off,
-                lp_ct);
+        fprintf(trace_fp, TRACE_FN_FOR_REPEAT, for_state->for_name, lp_ct);
 
         if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
             fprintf(trace_fp, TAB_FILE_LINE_FMT, tpl->td_file, mac->md_line);
     }
 
+    if (for_state->for_sep_str != NULL)
+        AGFREE(for_state->for_sep_str);
+
+    free_for_context(false);
+
     return ret_mac;
 }
 
@@ -791,7 +815,9 @@ new_for_context(void)
      */
     if (++(curr_ivk_info->ii_for_depth) > curr_ivk_info->ii_for_alloc) {
         void * dta = curr_ivk_info->ii_for_data;
-        size_t sz  = (curr_ivk_info->ii_for_alloc += 5) * sizeof(for_state_t);
+        size_t sz;
+        curr_ivk_info->ii_for_alloc += 5;
+        sz  = (size_t)curr_ivk_info->ii_for_alloc * sizeof(for_state_t);
 
         if (dta == NULL)
              dta = AGALOC(sz, "Init FOR sate");
@@ -858,10 +884,10 @@ mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
 
     /*
      *  src points to the name of the iteration "variable"
-     *  Special hack:  if the name is preceeded by a `.',
+     *  Special hack:  if the name is preceded by a `.',
      *  then the lookup is local-only and we will accept it.
      */
-    mac->md_name_off = tpl->td_scan - tpl->td_text;
+    mac->md_name_off = (uintptr_t)(tpl->td_scan - tpl->td_text);
     if (*scan_in == '.') {
         *(scan_out++) = *(scan_in++);
         if (! IS_VAR_FIRST_CHAR(*scan_in))
@@ -878,7 +904,7 @@ mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
      *  Skip space to the start of the text following the iterator name
      */
     scan_in = SPN_WHITESPACE_CHARS(scan_in);
-    in_len -= scan_in - (char*)mac->md_txt_off;
+    in_len -= (size_t)(scan_in - (char*)mac->md_txt_off);
 
     /* * * * *
      *
@@ -903,7 +929,7 @@ mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
      *  *OR*         FOR foo (scheme ...) ...
      */
     else {
-        mac->md_txt_off = scan_out - tpl->td_text;
+        mac->md_txt_off = (uintptr_t)(scan_out - tpl->td_text);
         memmove(scan_out, scan_in, in_len);
         scan_out[in_len] = NUL;
         if (IS_QUOTE_CHAR(*scan_out))
@@ -919,13 +945,15 @@ mLoad_For(templ_t * tpl, macro_t * mac, char const ** p_scan)
         if (*p_scan == NULL)
             AG_ABEND_IN(tpl, mac, LD_FOR_NO_ENDFOR);
 
-        mac->md_end_idx = mac->md_sib_idx = next_mac - tpl->td_macros;
+        mac->md_end_idx = mac->md_sib_idx = (int)(next_mac - tpl->td_macros);
 
         load_proc_table = save_load_procs;
         return next_mac;
     }
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
