@@ -2,14 +2,18 @@
 /**
  * \file boolean.c
  *
- *   Automated Options Paged Usage module.
+ * Handle options with true/false values for arguments.
  *
+ * @addtogroup autoopts
+ * @{
+ */
+/*
  *  This routine will run run-on options through a pager so the
  *  user may examine, print or edit them at their leisure.
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -21,19 +25,19 @@
  *   The Modified Berkeley Software Distribution License
  *      See the file "COPYING.mbsd"
  *
- *  These files have the following md5sums:
+ *  These files have the following sha256 sums:
  *
- *  43b91e8ca915626ed3818ffb1b71248b pkg/libopts/COPYING.gplv3
- *  06a1a2e4760c90ea5e1dad8dfaac4d39 pkg/libopts/COPYING.lgplv3
- *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
+ *  8584710e9b04216a394078dc156b781d0b47e1729104d666658aecef8ee32e95  COPYING.gplv3
+ *  4379e7444a0e2ce2b12dd6f5a52a27a4d02d39d247901d3285c88cf0d37f477b  COPYING.lgplv3
+ *  13aa749a5b0a454917a944ed8fffc530b784f5ead522b1aacaf4ec8aa55a6239  COPYING.mbsd
  */
 
 /*=export_func  optionBooleanVal
  * private:
  *
  * what:  Decipher a boolean value
- * arg:   + tOptions* + pOpts    + program options descriptor +
- * arg:   + tOptDesc* + pOptDesc + the descriptor for this arg +
+ * arg:   + tOptions* + opts + program options descriptor +
+ * arg:   + tOptDesc* + od  + the descriptor for this arg +
  *
  * doc:
  *  Decipher a true or false value for a boolean valued option argument.
@@ -41,28 +45,23 @@
  *  it is an empty string or it is a number that evaluates to zero.
 =*/
 void
-optionBooleanVal(tOptions * pOpts, tOptDesc * pOD )
+optionBooleanVal(tOptions * opts, tOptDesc * od)
 {
     char* pz;
     bool  res = true;
 
-    (void)pOpts;
-
-    if (pOpts <= OPTPROC_EMIT_LIMIT)
+    if (INQUERY_CALL(opts, od))
         return;
 
-    if ((pOD->fOptState & OPTST_RESET) != 0)
-        return;
-
-    if (pOD->optArg.argString == NULL) {
-        pOD->optArg.argBool = false;
+    if (od->optArg.argString == NULL) {
+        od->optArg.argBool = false;
         return;
     }
 
-    switch (*(pOD->optArg.argString)) {
+    switch (*(od->optArg.argString)) {
     case '0':
     {
-        long  val = strtol( pOD->optArg.argString, &pz, 0 );
+        long  val = strtol(od->optArg.argString, &pz, 0);
         if ((val != 0) || (*pz != NUL))
             break;
         /* FALLTHROUGH */
@@ -75,18 +74,19 @@ optionBooleanVal(tOptions * pOpts, tOptDesc * pOD )
         res = false;
         break;
     case '#':
-        if (pOD->optArg.argString[1] != 'f')
+        if (od->optArg.argString[1] != 'f')
             break;
         res = false;
     }
 
-    if (pOD->fOptState & OPTST_ALLOC_ARG) {
-        AGFREE(pOD->optArg.argString);
-        pOD->fOptState &= ~OPTST_ALLOC_ARG;
+    if (od->fOptState & OPTST_ALLOC_ARG) {
+        AGFREE(od->optArg.argString);
+        od->fOptState &= ~OPTST_ALLOC_ARG;
     }
-    pOD->optArg.argBool = res;
+    od->optArg.argBool = res;
 }
-/*
+/** @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
