@@ -2,7 +2,7 @@
 
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
-##  AutoOpts is Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
+##  AutoOpts is Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
 ##
 ##  AutoOpts is available under any one of two licenses.  The license
 ##  in use must be one of these two and the choice is under the control
@@ -152,9 +152,83 @@ set_cat_prog() {
     done
 }
 
+scan_cflags() {
+    libguiledir=
+    while test $# -gt 0
+    do
+        case "$1" in
+        -I )
+            test -f $2/libguile/__scm.h && {
+                libguiledir=$2
+                return 0
+            }
+            ;;
+        -I* )
+            f=${1#-I}
+            test -f $f/libguile/__scm.h && {
+                libguiledir=$f
+                return 0
+            }
+            ;;
+        esac
+        shift
+    done
+
+    libguiledir=/usr/include
+    test -f $libguiledir/libguile/__scm.h && return 0
+    die "The Guile header __scm.h cannot be found"
+}
+
+find_libguiledir() {
+    guile_scm_h=
+    libguiledir=`exec 2>/dev/null ; guile-config info includedir`
+
+    if test -d "${libguiledir}"
+    then
+        test -d ${libguiledir}/guile && libguiledir=${libguiledir}/guile
+        v=`guile-config --version 2>&1 | sed 's/.* version //'`
+        test -d ${libguiledir}/${v%.*} && v=${v%.*}
+        test -d ${libguiledir}/${v} && libguiledir=${libguiledir}/$v
+
+    else
+        scan_cflags "$@"
+    fi
+    guile_scm_h=`find ${libguiledir} -type f -name __scm.h`
+}
+
+fix_guile() {
+    cd ${builddir}
+    find_libguiledir "${LGCFLAGS}"
+
+    list=`set +e ; exec 2>/dev/null
+        find ${libguiledir}/libguile* -type f | \
+            xargs grep -l -E '\<noreturn\>'`
+
+    test -z "$list" && exit 0
+
+    test -d libguile || mkdir libguile || {
+        echo "cannot make libguile directory"
+        exit 1
+    } 1>&2
+
+    noret='\([^a-zA-Z0-9_]\)noreturn\([^a-zA-Z0-9_]\)'
+    nores='\1__noreturn__\2'
+    sedex="s@${noret}@${nores}@"
+
+    for f in $list
+    do
+        g=libguile${f##*/libguile}
+        sed "${sedex}" $f > $g
+        diff -u $f $g >&2 || :
+    done
+
+    test -f libguile.h || cp ${libguiledir}/libguile.h .
+}
+
 init
 collect_src "$@" > ${builddir}/libopts.c
 extension_defines
 set_shell_prog
 set_cat_prog
+fix_guile
 touch ${sentinel_file}
